@@ -550,7 +550,7 @@ class Camera():
             self.frame = cv2.circle( self.frame, ( round(face.right_iris.center_x) , round(face.right_iris.center_y) ),
                                 round( min( [face.left_iris.width, face.left_iris.height] ) * 0.5 ), (0,255,0), 2 )
 
-    def write_direction(self, faces):
+    def show_direction(self, faces):
         for face in faces:
             self.frame = cv2.putText(self.frame, face.head_pose.text, org=(int(face.x1), int(face.y1 - 15)),
                 fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=1, color=(0, 255, 0), thickness=2)
@@ -574,7 +574,7 @@ class Camera():
             for i in range(21):
                 self.frame = cv2.circle(self.frame, (hand.landmark_list[i][0] , hand.landmark_list[i][1]), 4, (255, 0, 255), cv2.FILLED)
 
-    def write_shape(self, hands):
+    def show_shape(self, hands):
         for hand in hands:
             
             text = hand.detect_gesture()
@@ -585,7 +585,7 @@ class Camera():
                             fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=1, color=(255, 255, 255), thickness=2)
     
 
-    def write_hand_distance(self, hands):
+    def show_distance(self, hands):
         for hand in hands:
             x,y,w,h = hand.bbox
             distanceCM = hand.get_distance()
@@ -595,7 +595,7 @@ class Camera():
 
 
     def detect_face(self, frame, max_num_face = 1 , draw_face = True, draw_lips = True, draw_eyes = True, draw_irides = True,
-                    write_direction = True) -> object or None:
+                    show_direction = True) -> object or None:
 
         mp_face_mesh = mp.solutions.face_mesh
 
@@ -626,8 +626,8 @@ class Camera():
             self.draw_eyes(face)
         if draw_irides:
             self.draw_irides(face)
-        if write_direction:
-            self.write_direction(face)
+        if show_direction:
+            self.show_direction(face)
 
         if len(face) == 1 and max_num_face == 1:
             return face[0]
@@ -635,7 +635,7 @@ class Camera():
         return None
 
     def detect_faces(self, frame, max_num_faces = 99, draw_faces =True, draw_lips = True, draw_eyes = True, draw_irides = True,
-                    write_direction = True) -> list:
+                    show_direction = True) -> list:
  
         mp_face_mesh = mp.solutions.face_mesh
 
@@ -666,12 +666,12 @@ class Camera():
             self.draw_eyes(faces)
         if draw_irides:
             self.draw_irides(faces)
-        if write_direction:
-            self.write_direction(faces)
+        if show_direction:
+            self.show_direction(faces)
 
         return faces
 
-    def detect_hand(self, frame, max_num_hand = 1, draw_hand = True, write_shape = False, write_hand_distance = False):
+    def detect_hand(self, frame, max_num_hand = 1, draw_hand = True, show_shape = False, show_distance = False):
         mp_hands = mp.solutions.hands
 
         hand = []
@@ -695,17 +695,17 @@ class Camera():
 
         if draw_hand:
             self.draw_hands(hand)
-        if write_shape:
-            self.write_shape(hand)
-        if write_hand_distance:
-            self.write_hand_distance(hand)
+        if show_shape:
+            self.show_shape(hand)
+        if show_distance:
+            self.show_distance(hand)
 
         if len(hand) == 1 and max_num_hand == 1:
             return hand[0]
 
         return None
 
-    def detect_hands(self, frame, max_num_hands = 99, draw_hands = True, write_shape = False, write_hand_distance = False):
+    def detect_hands(self, frame, max_num_hands = 99, draw_hands = True, show_shape = False, show_distance = False):
         mp_hands = mp.solutions.hands
 
         hands = []
@@ -729,10 +729,10 @@ class Camera():
 
         if draw_hands:
             self.draw_hands(hands)
-        if write_shape:
-            self.write_shape(hands)
-        if write_hand_distance:
-            self.write_hand_distance(hands)
+        if show_shape:
+            self.show_shape(hands)
+        if show_distance:
+            self.show_distance(hands)
 
         return hands
 
